@@ -4,11 +4,12 @@
     Django-flash
     ~~~~~~~~~~~~
 
-    Rails-like flash scope support for Django.
+    Rails-like *flash* messages support for Django.
+
 
     :copyright: 2008-2009, Destaquenet Technology Solutions.
-    :license: LGPL v3.
+    :license: BSD.
 """
 
-__version__ = '1.4.4'
+__version__ = '1.5'
 
