@@ -3,11 +3,12 @@
 """Integration test cases.
 """
 
+from django.core.exceptions import SuspiciousOperation
 from django.core.urlresolvers import reverse
 from django.test import TestCase
 
 from djangoflash.context_processors import CONTEXT_VAR
-from djangoflash.middleware import FlashMiddleware
+from djangoflash.middleware import FlashScope
 
 from testproj.app import views
 
@@ -17,29 +18,12 @@ class IntegrationTestCase(TestCase):
     Django application.
     """
     def _flash(self):
-        """Shortcut to get the flash scope from the view context.
+        """Shortcut to get the flash from the view context.
         """
         return self.response.context[CONTEXT_VAR]
 
-    def test_session_state_for_unused_flash(self):
-        """Flash scope shouldn't be stored in the session if there's no flash.
-        """
-        self.response = self.client.get(reverse(views.render_template))
-        self.assertFalse(FlashMiddleware._SESSION_KEY in self.client.session)
-
-    def test_session_state_for_used_flash(self):
-        """Flash scope should be removed from the session if there's no flash.
-        """
-        self.response = self.client.get(reverse(views.set_flash_var))
-        self.response = self.client.get(reverse(views.render_template))
-        self.assertTrue(FlashMiddleware._SESSION_KEY in self.client.session)
-
-        # Flash scope should be removed from the session
-        self.response = self.client.get(reverse(views.render_template))
-        self.assertFalse(FlashMiddleware._SESSION_KEY in self.client.session)
-
     def test_default_lifecycle(self):
-        """A value should be automatically removed from the flash scope.
+        """A value should be automatically removed from the flash.
         """
         self.response = self.client.get(reverse(views.set_flash_var))
         self.assertEqual('Message', self._flash()['message'])
@@ -52,7 +36,7 @@ class IntegrationTestCase(TestCase):
         self.assertFalse('message' in self._flash())
 
     def test_keep_lifecycle(self):
-        """A value shouldn't be removed from the flash scope when it is kept.
+        """A value shouldn't be removed from the flash when it is kept.
         """
         self.response = self.client.get(reverse(views.set_flash_var))
         self.assertEqual('Message', self._flash()['message'])
@@ -89,7 +73,7 @@ class IntegrationTestCase(TestCase):
         self.assertFalse('message' in self._flash())
 
     def test_multiple_variables_lifecycle(self):
-        """The flash scope should control several values independently.
+        """The flash should control several values independently.
         """
         self.response = self.client.get(reverse(views.set_flash_var))
         self.assertEqual('Message', self._flash()['message'])
@@ -108,14 +92,13 @@ class IntegrationTestCase(TestCase):
         self.assertFalse('message' in self._flash())
         self.assertFalse('anotherMessage' in self._flash())
 
-    def test_replace_flash_scope(self):
-        """The flash scope should be an instance of FlashScope.
-        """
-        request = lambda: self.client.get(reverse(views.replace_flash))
-        self.assertRaises(TypeError, request)
-
-    def test_remove_flash_scope(self):
-        """The app should not break even if request.flash doesn't exists.
+    def test_remove_flash(self):
+        """An empty flash should be provided when none is available.
         """
         self.response = self.client.get(reverse(views.remove_flash))
-        self.assertFalse(self._flash() is None)
+        self.assertTrue(isinstance(self._flash(), FlashScope))
+
+    def test_replace_flash_with_invalid_object(self):
+        """An exception should be raised when exposing an invalid object as being the flash.
+        """
+        self.assertRaises(SuspiciousOperation, self.client.get, reverse(views.replace_flash))
